@@ -16,7 +16,11 @@ mod wasmi;
 mod wasmtime;
 
 pub use self::{
-    executor::*,
-    result::{Error, Result, ReturnCode},
+    builder::Builder,
+    executor::Executor,
+    instance::Instance,
+    memory::{scan_imports, Memory},
+    result::{Error, ExecResult, Result, ReturnCode, ReturnData, ReturnFlags},
     trap::{Trap, TrapCode},
+    value::Value,
 };
